Skip to contents

The CiteSource package supports evidence aggregation by helping with the processing of results of various searches in different sources. It allows to deduplicate results while retaining meta-data on where those results were found and then enables users to compare the contribution of different sources.

Author

Maintainer: Trevor Riley tnriley@gmail.com (ORCID)

Authors:

Other contributors:

  • Martin Westgate (Author of included synthesisr fragments) [copyright holder]

  • Eliza Grames (Author of included synthesisr fragments) [copyright holder]

  • Kaitlyn Hair (Author of included ASySD deduplication code) [copyright holder]

  • CAMARADES Group (Authors of ASySD (github.com/camaradesuk/ASySD)) [copyright holder]